# Addok plugin for French support

## Installation

    pip install addok-fr


## Configuration

- Add `phonemicize` into PROCESSORS_PYPATHS:

    PROCESSORS_PYPATHS = [
        …,
        'addok_fr.phonemicize'
    ]
